/*
 * Copyright 2010 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gradle.language.base.internal.tasks;

import org.gradle.api.internal.TaskOutputsInternal;

import java.io.File;

public class SimpleStaleClassCleaner extends StaleClassCleaner {
    private final TaskOutputsInternal taskOutputs;
    private boolean didWork;

    public SimpleStaleClassCleaner(TaskOutputsInternal taskOutputs) {
        this.taskOutputs = taskOutputs;
    }

    @Override
    public void execute() {
        String prefix = getDestinationDir().getAbsolutePath() + File.separator;
        for (File f : taskOutputs.getPreviousOutputFiles()) {
            if (f.getAbsolutePath().startsWith(prefix) && f.isFile()) {
                didWork |= f.delete();
            }
        }
    }

    public boolean getDidWork() {
        return didWork;
    }
}
